====================================
database - Public database interface
====================================

The database interface class :class:`database.DBInterface` requires a valid
connection string (or database URL) on instantiation. For convenience,
the connection string templates and associated documentation can be
found in the :ref:`using-the-library` --> :ref:`connection-strings`
section of this documentation.

.. automodule:: database
    :members:
    :undoc-members:
    :private-members:
    :special-members:
    :exclude-members: __dict__, __module__, __weakref__
